@@ -1,3 +1,10 @@
+/*
+ * $Id: logging.h,v 1.7 1999/12/30 05:42:35 mason Exp $
+ */
+
+#ifndef _LOGGING_H_
+#define _LOGGING_H_
+
 #ifdef UTMP_SUPPORT
 # if ! defined(HAVE_STRUCT_UTMPX) && ! defined(HAVE_STRUCT_UTMP)
 #  error cannot build with utmp support - no utmp or utmpx struct found
@@ -84,3 +91,4 @@
 
 #include "logging.intpro"		/* PROTOS for internal routines */
 #endif
+#endif /* _LOGGING_H_ */
