@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	menubar.c
  *----------------------------------------------------------------------*
- * $Id: menubar.c,v 1.32 1999/10/03 12:01:56 mason Exp $
+ * $Id: menubar.c,v 1.34 2000/01/14 05:05:05 mason Exp $
  *
  * Copyright (C) 1997,1998  mj olesen <olesen@me.QueensU.CA>
  *
@@ -113,7 +113,7 @@ menuitem_free(menu_t *menu, menuitem_t *item)
 	FREE(item->entry.action.str);
 	break;
     case MenuSubMenu:
-	(void)menu_delete(item->entry.submenu.menu);
+	menu_delete(item->entry.submenu.menu);
 	break;
     }
     if (item->name != NULL)
@@ -949,22 +949,37 @@ menu_show(void)
 	    } else if (item->name2 && !STRCMP(name, item->name2))
 		name = NULL;
 
-	    if (len && name)
-		XDrawString(Xdisplay,
-			    ActiveMenu->win, gc,
-			    xoff,
-			    2 * SHADOW + y + TermWin.font->ascent + 1,
-			    name, len);
+	    if (len && name) {
+                if (TermWin.fontset)
+		    XmbDrawString(Xdisplay,
+				  ActiveMenu->win, TermWin.fontset, gc,
+				  xoff,
+				  2 * SHADOW + y + TermWin.font->ascent + 1,
+				  name, len);
+                else
+		    XDrawString(Xdisplay,
+				ActiveMenu->win, gc,
+				xoff,
+				2 * SHADOW + y + TermWin.font->ascent + 1,
+				name, len);
+	    }
 
 	    len = item->len2;
 	    name = item->name2;
-	    if (len && name)
-		XDrawString(Xdisplay,
+	    if (len && name) {
+                if (TermWin.fontset)
+		    XmbDrawString(Xdisplay,
+				ActiveMenu->win, TermWin.fontset, gc,
+				ActiveMenu->w - (xoff + Width2Pixel(xright)),
+				2 * SHADOW + y + TermWin.font->ascent + 1,
+				name, len);
+                else
+		    XDrawString(Xdisplay,
 			    ActiveMenu->win, gc,
 			    ActiveMenu->w - (xoff + Width2Pixel(xright)),
 			    2 * SHADOW + y + TermWin.font->ascent + 1,
 			    name, len);
-
+	    }
 	    h = HEIGHT_TEXT + 2 * SHADOW;
 	}
 	y += h;
@@ -1442,7 +1457,7 @@ menubar_read(const char *filename)
      * and strip-off leading/trailing quotes
      * skip blank or comment lines
      */
-	(void) Str_trim(p);
+	Str_trim(p);
 	if (*p && *p != '#') {
 	    menu_readonly = 0;	/* if case we read another file */
 	    menubar_dispatch(p);
@@ -1889,12 +1904,18 @@ menubar_expose(void)
 		len = (TermWin.ncol - (menu->x + HSPACE));
 
 	    drawbox_menubar(menu->x, len, +1);
-
-	    XDrawString(Xdisplay,
-			menuBar.win, menubarGC,
-			(Width2Pixel(menu->x) + Width2Pixel(HSPACE) / 2),
-			menuBar_height() - SHADOW,
-			menu->name, len);
+	    if (TermWin.fontset)
+		XmbDrawString(Xdisplay,
+			      menuBar.win, TermWin.fontset, menubarGC,
+			      (Width2Pixel(menu->x) + Width2Pixel(HSPACE) / 2),
+			      menuBar_height() - SHADOW,
+			      menu->name, len);
+	    else
+		XDrawString(Xdisplay,
+			    menuBar.win, menubarGC,
+			    (Width2Pixel(menu->x) + Width2Pixel(HSPACE) / 2),
+			    menuBar_height() - SHADOW,
+			    menu->name, len);
 
 	    if (x >= TermWin.ncol)
 		break;
@@ -1947,12 +1968,20 @@ menubar_expose(void)
 	title[len] = '\0';
 
 	ncol -= (x + len + HSPACE);
-	if (len > 0 && ncol >= 0)
-	    XDrawString(Xdisplay,
-			menuBar.win, menubarGC,
-			Width2Pixel(x) + Width2Pixel(ncol + HSPACE) / 2,
-			menuBar_height() - SHADOW,
-			title, len);
+	if (len > 0 && ncol >= 0) {
+	    if (TermWin.fontset)
+		XmbDrawString(Xdisplay,
+			      menuBar.win, TermWin.fontset, menubarGC,
+			      Width2Pixel(x) + Width2Pixel(ncol + HSPACE) / 2,
+			      menuBar_height() - SHADOW,
+			      title, len);
+	    else
+		XDrawString(Xdisplay,
+			    menuBar.win, menubarGC,
+			    Width2Pixel(x) + Width2Pixel(ncol + HSPACE) / 2,
+			    menuBar_height() - SHADOW,
+			    title, len);
+	}
     }
 }
 
