@@ -1,9 +1,9 @@
 /*
- * $Id: rxvt.h,v 1.65 1999/12/18 07:41:47 mason Exp $
+ * $Id: rxvt.h,v 1.70 2000/02/27 04:57:52 mason Exp $
  */
 
-#ifndef _RXVT_H			/* include once only */
-#define _RXVT_H
+#ifndef _RXVT_H_		/* include once only */
+#define _RXVT_H_
 
 #include "feature.h"
 
@@ -99,6 +99,8 @@
 #include <X11/Intrinsic.h>	/* Xlib, Xutil, Xresource, Xfuncproto */
 #include <X11/cursorfont.h>
 #include <X11/keysym.h>
+#include <X11/keysymdef.h>
+#include <X11/Xatom.h>
 
 #include "rsizes.h"		/* we've pulled in <sys/types.h> - presumed */
 #ifndef HAVE_XPOINTER
@@ -450,6 +452,8 @@ enum {
 #define Opt_Reverse		(1LU<<30)
 #define Opt_Boolean		(1LU<<31)
 
+#define DEFAULT_OPTIONS		(Opt_scrollBar | Opt_scrollTtyOutput)
+
 /*
  * XTerm escape sequences: ESC ] Ps;Pt BEL
  */
@@ -609,6 +613,43 @@ typedef struct {
  */
 #define	NGRX_PTS	1000
 
+/* DEC private modes */
+#define PrivMode_132		(1LU<<0)
+#define PrivMode_132OK		(1LU<<1)
+#define PrivMode_rVideo		(1LU<<2)
+#define PrivMode_relOrigin	(1LU<<3)
+#define PrivMode_Screen		(1LU<<4)
+#define PrivMode_Autowrap	(1LU<<5)
+#define PrivMode_aplCUR		(1LU<<6)
+#define PrivMode_aplKP		(1LU<<7)
+#define PrivMode_HaveBackSpace	(1LU<<8)
+#define PrivMode_BackSpace	(1LU<<9)
+#define PrivMode_ShiftKeys	(1LU<<10)
+#define PrivMode_VisibleCursor	(1LU<<11)
+#define PrivMode_MouseX10	(1LU<<12)
+#define PrivMode_MouseX11	(1LU<<13)
+#define PrivMode_scrollBar	(1LU<<14)
+#define PrivMode_menuBar	(1LU<<15)
+#define PrivMode_TtyOutputInh	(1LU<<16)
+#define PrivMode_Keypress	(1LU<<17)
+/* too annoying to implement X11 highlight tracking */
+/* #define PrivMode_MouseX11Track       (1LU<<18) */
+
+#define PrivMode_mouse_report	(PrivMode_MouseX10|PrivMode_MouseX11)
+#define PrivMode(test,bit)		\
+    if (test)				\
+	PrivateModes |= (bit);		\
+    else				\
+	PrivateModes &= ~(bit)
+
+#ifdef ALLOW_132_MODE
+# define PrivMode_Default						 \
+(PrivMode_Autowrap|PrivMode_aplKP|PrivMode_ShiftKeys|PrivMode_VisibleCursor|PrivMode_132OK)
+#else
+# define PrivMode_Default						 \
+(PrivMode_Autowrap|PrivMode_aplKP|PrivMode_ShiftKeys|PrivMode_VisibleCursor)
+#endif
+
 /*
  *****************************************************************************
  * MACRO DEFINES
@@ -717,6 +758,43 @@ typedef struct {
 
 #define Gr_ButtonPress(x,y)	Gr_ButtonReport ('P',(x),(y))
 #define Gr_ButtonRelease(x,y)	Gr_ButtonReport ('R',(x),(y))
+
+#ifdef DEBUG_CMD
+# define D_CMD(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_CMD(x)
+#endif
+#ifdef DEBUG_INIT
+# define D_INIT(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_INIT(x)
+#endif
+#ifdef DEBUG_MAIN
+# define D_MAIN(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_MAIN(x)
+#endif
+#ifdef DEBUG_SCREEN
+# define D_SCREEN(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_SCREEN(x)
+#endif
+#ifdef DEBUG_SELECT
+# define D_SELECT(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_SELECT(x)
+#endif
+#ifdef DEBUG_TTY
+# define D_TTY(x)		fprintf x ; fputc('\n', stderr)
+#else
+# define D_TTY(x)
+#endif
+#ifdef DEBUG_X
+# define D_X(x)			fprintf x ; fputc('\n', stderr)
+#else
+# define D_X(x)
+#endif
+
 /*
  *****************************************************************************
  * VARIABLES
@@ -724,8 +802,10 @@ typedef struct {
  */
 #ifdef INTERN
 # define EXTERN
+# define EXTERN_INIT(a)	= (a)
 #else
 # define EXTERN extern
+# define EXTERN_INIT(a)
 #endif
 
 #ifdef PREFER_24BIT
@@ -745,15 +825,46 @@ EXTERN Visual      *Xvisual;
 EXTERN TermWin_t	TermWin;
 EXTERN scrollBar_t	scrollBar;
 EXTERN menuBar_t	menuBar;
-EXTERN Display	       *Xdisplay;
-EXTERN unsigned long	Options;
+EXTERN Display	       *Xdisplay	EXTERN_INIT(NULL);
+EXTERN unsigned long	Options		EXTERN_INIT(DEFAULT_OPTIONS);
 EXTERN XSizeHints       szHint;
-EXTERN int		sb_shadow;
+EXTERN int		sb_shadow	EXTERN_INIT(0);
 EXTERN Pixel		PixColors[TOTAL_COLORS];
 #ifdef INEXPENSIVE_LOCAL_X_CALLS
 EXTERN int              display_is_local;
 #endif
-EXTERN short		want_refresh;
+EXTERN Atom		xa_compound_text	EXTERN_INIT(None);
+EXTERN Atom		xa_multiple	EXTERN_INIT(None);
+EXTERN Atom		xa_targets	EXTERN_INIT(None);
+EXTERN Atom		xa_text		EXTERN_INIT(None);
+EXTERN Atom		xa_timestamp	EXTERN_INIT(None);
+EXTERN Time		selection_time;
+EXTERN short		want_refresh	EXTERN_INIT(1);
+EXTERN Cursor		TermWin_cursor;	/* cursor for vt window */
+/* process id of child */
+EXTERN pid_t		cmd_pid		EXTERN_INIT(-1);
+/* pty/tty name */
+EXTERN char	       *ttydev		EXTERN_INIT(NULL);
+/* pty file descriptor; connected to command */
+EXTERN int		cmd_fd		EXTERN_INIT(-1);	
+/* tty file descriptor; connected to child */
+EXTERN int		tty_fd		EXTERN_INIT(-1);	
+/* file descriptor of X server connection */
+EXTERN int		Xfd		EXTERN_INIT(-1);	
+/* number of file descriptors being used */
+EXTERN int		num_fds		EXTERN_INIT(0);
+EXTERN short		changettyowner	EXTERN_INIT(1);
+EXTERN unsigned int     ModMetaMask	EXTERN_INIT(0);
+EXTERN unsigned int     ModNumLockMask	EXTERN_INIT(0);
+EXTERN unsigned long	PrivateModes	EXTERN_INIT(PrivMode_Default);
+EXTERN unsigned long	SavedModes	EXTERN_INIT(PrivMode_Default);
+#ifdef META8_OPTION
+EXTERN unsigned char	meta_char	EXTERN_INIT(0);	/* Alt-key prefix */
+#endif
+#ifdef TRANSPARENT
+EXTERN Atom		xrootpmapid;
+#endif
+EXTERN Atom		wmDeleteWindow;
 
 EXTERN resource_list    rs;
 
@@ -764,15 +875,22 @@ EXTERN const char      *key_backspace;
 EXTERN const char      *key_delete;
 #endif
 #ifndef NO_BRIGHTCOLOR
-EXTERN unsigned int	colorfgbg;
+EXTERN unsigned int	colorfgbg	EXTERN_INIT(DEFAULT_RSTYLE);
+#endif
+#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
+EXTERN KeySym		ks_bigfont	EXTERN_INIT(XK_greater);
+EXTERN KeySym		ks_smallfont	EXTERN_INIT(XK_less);
+#endif
+#ifdef USE_XIM
+EXTERN XIC		Input_Context	EXTERN_INIT(NULL);
+EXTERN XIMStyle		input_style	EXTERN_INIT(0);
+EXTERN int		event_type;
 #endif
 #ifdef KEYSYM_RESOURCE
 EXTERN const unsigned char *KeySym_map[256];
 #endif
-#if defined (HOTKEY_CTRL) || defined (HOTKEY_META)
-EXTERN KeySym		ks_bigfont;
-EXTERN KeySym		ks_smallfont;
-#endif
+
+#define IMBUFSIZ	128	/* input modifier buffer sizes */
 
 /*
  *****************************************************************************
@@ -826,8 +944,20 @@ EXTERN KeySym		ks_smallfont;
 # define greek_xlat(s, num_chars)	(0)
 #endif
 
+#ifndef USE_XIM
+# define setTermFontSet(idx)	(0)
+#endif
+
+#ifndef UTMP_SUPPORT
+# define privileged_utmp(action)	(0)
+#endif
+
+#ifdef __CYGWIN32__
+# define privileged_ttydev(action)	(0)
+#endif
+
 #ifdef DEBUG_MALLOC
 # include "dmalloc.h"		/* This comes last */
 #endif
 
-#endif				/* _RXVT_H */
+#endif /* _RXVT_H_ */
