@@ -1,5 +1,6 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	rxvtgrx.h
+ * $Id: rxvtgrx.h,v 1.3 1999/12/30 05:42:36 mason Exp $
  *
  * Stuff for text alignment for rxvt special graphics mode
  *
@@ -20,8 +21,8 @@
  *	text is placed so that the specified point is equidistant from the
  *	bottom and tops of capital letters
  *----------------------------------------------------------------------*/
-#ifndef _RXVTGRX_H
-#define _RXVTGRX_H
+#ifndef _RXVTGRX_H_
+#define _RXVTGRX_H_
 
 #define GRX_SCALE		10000
 
@@ -49,5 +50,5 @@
 # define TXT_VCAPS_CENTER	'C'
 #endif
 
-#endif	/* whole file */
+#endif /* _RXVTGRX_H_ */
 /*----------------------- end-of-file (C header) -----------------------*/
