@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	scrollbar.c
  *----------------------------------------------------------------------*
- * $Id: scrollbar.c,v 1.26 1999/12/18 04:44:23 mason Exp $
+ * $Id: scrollbar.c,v 1.27 2000/02/09 05:55:06 mason Exp $
  *
  * Copyright (C) 1997,1998 mj olesen <olesen@me.QueensU.CA>
  * Copyright (C) 1998      Alfredo K. Kojima <kojima@windowmaker.org>
@@ -280,7 +280,7 @@ init_scrollbar_stuff(void)
     xcol.red = 0xaeba;
     xcol.green = 0xaaaa;
     xcol.blue = 0xaeba;
-    if (!XAllocColor(Xdisplay, Xcmap, &xcol)) {
+    if (!rXAllocColor(Xdisplay, Xcmap, &xcol)) {
 	print_error("can't allocate %s", "light gray");
 	xcol.pixel = PixColors[Color_AntiqueWhite];
     }
@@ -291,7 +291,7 @@ init_scrollbar_stuff(void)
     xcol.red = 0x51aa;
     xcol.green = 0x5555;
     xcol.blue = 0x5144;
-    if (!XAllocColor(Xdisplay, Xcmap, &xcol)) {
+    if (!rXAllocColor(Xdisplay, Xcmap, &xcol)) {
 	print_error("can't allocate %s", "dark gray");
 	xcol.pixel = PixColors[Color_Grey25];
     }
