@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	xdefaults.c
  *----------------------------------------------------------------------*
- * $Id: xdefaults.c,v 1.51 1999/12/18 06:51:24 mason Exp $
+ * $Id: xdefaults.c,v 1.57 2000/03/11 05:14:50 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1994      Robert Nation <nation@rocket.sanders.lockheed.com>
@@ -101,7 +101,7 @@ static const struct {
 	 Opt_scrollBar_floating, "scrollbar without a trough"),
     BOOL(rs.scrollTtyOutput, "scrollTtyOutput", NULL, Opt_scrollTtyOutput,
 	 NULL),
-    SWCH("si", Opt_Boolean | Opt_Reverse | Opt_scrollTtyOutput,
+    BOOL(rs.scrollTtyOutput, NULL, "si", Opt_Reverse | Opt_scrollTtyOutput,
 	 "scroll-on-tty-output inhibit"),
     BOOL(rs.scrollKeypress, "scrollTtyKeypress", "sk", Opt_scrollKeypress,
 	 "scroll-on-keypress"),
@@ -211,7 +211,7 @@ static const struct {
 #endif				/* MULTICHAR_SET */
 #ifdef MULTICHAR_SET
     STRG(rs.multichar_encoding, "multichar_encoding", "km", "mode",
-	 "multiple-character font encoding; mode = eucj | sjis | big5 | gb | kr"),
+	 "multiple-character font encoding; mode = eucj | sjis | big5 | gb | kr | noenc"),
 #endif				/* MULTICHAR_SET */
 #ifdef USE_XIM
     STRG(rs.preeditType, "preeditType", "pt", "style",
@@ -614,7 +614,7 @@ parse_keysym(const char *str, const char *arg)
 	newargstr[NEWARGLIM - 1] = '\0';
 	newarg = newargstr;
     }
-    (void)Str_trim(newarg);
+    Str_trim(newarg);
     if (*newarg == '\0' || (n = Str_escaped(newarg)) == 0)
 	return -1;
     MIN_IT(n, 255);
@@ -667,7 +667,7 @@ get_xdefaults(FILE *stream, const char *name)
 		if (str[n] == ':' && Str_match(str, kw)) {
 		    /* skip `keyword:' */
 		    str += (n + 1);
-		    (void)Str_trim(str);
+		    Str_trim(str);
 		    n = STRLEN(str);
 		    if (n && *(optList[entry].dp) == NULL) {
 			/* not already set */
@@ -718,7 +718,7 @@ extract_resources(Display *display, const char *name)
 
 #  ifdef XrmEnumOneLevel
     int             i;
-    char           *displayResource, *ptr, *xe;
+    char           *displayResource, *xe;
     XrmName         name_prefix[3];
     XrmClass        class_prefix[3];
     XrmDatabase     database, rdb1;
@@ -733,17 +733,26 @@ extract_resources(Display *display, const char *name)
     if (displayResource != NULL)
 	database = XrmGetStringDatabase(displayResource);
 
-/* Add in ~/.Xdefaults & ~/.Xresources */
+#ifdef HAVE_EXTRA_XRESOURCE_FILES
+/* Add in ~/.Xdefaults or ~/.Xresources */
+    {
+	char           *ptr;
 
-    if ((ptr = (char *)getenv("HOME")) == NULL)
-	ptr = ".";
+	if ((ptr = (char *)getenv("HOME")) == NULL)
+	    ptr = ".";
 
-    for (i = 0; i < (sizeof(xnames) / sizeof(xnames[0])); i++) {
-	sprintf(fname, "%-.*s/%s", sizeof(fname) - STRLEN(xnames[i]) - 2, ptr,
-		xnames[i]);
-	if ((rdb1 = XrmGetFileDatabase(fname)) != NULL)
-	    XrmMergeDatabases(rdb1, &database);
+	for (i = 0; i < (sizeof(xnames) / sizeof(xnames[0])); i++) {
+	    sprintf(fname, "%-.*s/%s", sizeof(fname) - STRLEN(xnames[i]) - 2,
+		    ptr, xnames[i]);
+	    if ((rdb1 = XrmGetFileDatabase(fname)) != NULL) {
+		XrmMergeDatabases(rdb1, &database);
+# ifndef HAVE_BOTH_XRESOURCE_FILES
+		break;
+# endif
+	    }
+	}
     }
+#endif
 
 /* Add in XENVIRONMENT file */
 
