@@ -1,12 +1,12 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	xpm.c
  *----------------------------------------------------------------------*
- * $Id: xpm.c,v 1.28 1999/03/11 14:09:21 mason Exp $
+ * $Id: xpm.c,v 1.33 1999/12/13 03:05:20 mason Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1997      Carsten Haitzler <raster@zip.com.au>
  * Copyright (C) 1997,1998 Oezguer Kesim <kesim@math.fu-berlin.de>
- * Copyright (C) 1998      Geoff Wing <gcw@pobox.com>
+ * Copyright (C) 1998,1999 Geoff Wing <gcw@pobox.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *---------------------------------------------------------------------*/
 
+#include "../config.h"		/* NECESSARY */
 #include "rxvt.h"		/* NECESSARY */
 #include "xpm.intpro"		/* PROTOS for internal routines */
 
@@ -32,19 +33,16 @@
 # else
 #  include <xpm.h>
 # endif
-#endif
 
 typedef struct {
     short           w, h, x, y;
     Pixmap          pixmap;
 } bgPixmap_t;
 
-static bgPixmap_t bgPixmap = { 0, 0, 50, 50, None } ;
+static bgPixmap_t bgPixmap = { 0, 0, 50, 50, None };
 
 /* the originally loaded pixmap and its scaling */
-#ifdef XPM_BACKGROUND
 static XpmAttributes xpmAttr;
-#endif
 
 /*
  * These GEOM strings indicate absolute size/position:
@@ -70,7 +68,6 @@ static XpmAttributes xpmAttr;
 int
 scale_pixmap(const char *geom)
 {
-#ifdef XPM_BACKGROUND
     int             w = 0, h = 0, x = 0, y = 0;
     int             n, flags, changed = 0;
     char           *p;
@@ -78,7 +75,7 @@ scale_pixmap(const char *geom)
 
     if (geom == NULL)
 	return 0;
-    if (!strcmp(geom, "?")) {
+    if (!STRCMP(geom, "?")) {
 	sprintf(str, "[%dx%d+%d+%d]",	/* can't presume snprintf? */
 		(bgPixmap.w < 9999 ? bgPixmap.w : 9999),
 		(bgPixmap.h < 9999 ? bgPixmap.h : 9999),
@@ -88,15 +85,16 @@ scale_pixmap(const char *geom)
 	return 0;
     }
 
-    if ((p = strchr(geom, ';')) == NULL)
-        p = strchr(geom, '\0');
+    if ((p = STRCHR(geom, ';')) == NULL)
+	p = STRCHR(geom, '\0');
     n = (p - geom);
     if (n >= sizeof(str) - 1)
-        return 0;
+	return 0;
     STRNCPY(str, geom, n);
     str[n] = '\0';
 
-    flags = XParseGeometry(str, &x, &y, (unsigned int *) &w, (unsigned int *) &h);
+    flags = XParseGeometry(str, &x, &y, (unsigned int *)&w,
+			   (unsigned int *)&h);
     if (!flags) {
 	flags |= WidthValue;
 	w = 0;
@@ -157,16 +155,12 @@ scale_pixmap(const char *geom)
 	changed++;
     }
     return changed;
-#else
-    return 0;
-#endif				/* XPM_BACKGROUND */
 }
 
 /* EXTPROTO */
 void
 resize_pixmap(void)
 {
-#ifdef XPM_BACKGROUND
     XGCValues       gcvalue;
     GC              gc;
     int             tiled = 0;
@@ -192,9 +186,9 @@ resize_pixmap(void)
 	int             w = bgPixmap.w, h = bgPixmap.h,
 			x = bgPixmap.x, y = bgPixmap.y;
 
-    /*
-     * don't zoom pixmap too much nor expand really small pixmaps
-     */
+	/*
+	 * don't zoom pixmap too much nor expand really small pixmaps
+	 */
 	if (w > 1000 || h > 1000)
 	    w = 1;
 	else if (width > (10 * xpmAttr.width)
@@ -202,7 +196,7 @@ resize_pixmap(void)
 	    w = 0;		/* tile */
 
 	if (w == 0) {
-	/* basic X tiling - let the X server do it */
+	    /* basic X tiling - let the X server do it */
 	    TermWin.pixmap = XCreatePixmap(Xdisplay, TermWin.vt,
 					   xpmAttr.width, xpmAttr.height,
 					   Xdepth);
@@ -215,9 +209,9 @@ resize_pixmap(void)
 
 	    TermWin.pixmap = XCreatePixmap(Xdisplay, TermWin.vt,
 					   width, height, Xdepth);
-	/*
-	 * horizontal scaling
-	 */
+	    /*
+	     * horizontal scaling
+	     */
 	    incr = (float)xpmAttr.width;
 	    p = 0;
 
@@ -231,7 +225,7 @@ resize_pixmap(void)
 		    x = 0;
 		    w = width;
 		}
-	    } else if (w < 10) { /* fit W images across screen */
+	    } else if (w < 10) {	/* fit W images across screen */
 		incr *= w;
 		x = 0;
 		w = width;
@@ -279,14 +273,14 @@ resize_pixmap(void)
 		    p = 0;
 		if (x < 0)
 		    continue;
-	    /* copy one column from the original pixmap to the tmp pixmap */
+		/* copy one column from the original pixmap to the tmp pixmap */
 		XCopyArea(Xdisplay, bgPixmap.pixmap, tmp, gc,
 			  (int)p, 0, 1, xpmAttr.height, x, 0);
 	    }
 
-	/*
-	 * vertical scaling
-	 */
+	    /*
+	     * vertical scaling
+	     */
 	    incr = (float)xpmAttr.height;
 	    p = 0;
 
@@ -300,7 +294,7 @@ resize_pixmap(void)
 		    y = 0;
 		    h = height;
 		}
-	    } else if (h < 10) { /* fit H images across screen */
+	    } else if (h < 10) {	/* fit H images across screen */
 		incr *= h;
 		y = 0;
 		h = height;
@@ -340,8 +334,7 @@ resize_pixmap(void)
 	    incr /= height;
 
 	    if (y > 0)
-		XFillRectangle(Xdisplay, TermWin.pixmap, gc, 0, 0,
-			       width, y);
+		XFillRectangle(Xdisplay, TermWin.pixmap, gc, 0, 0, width, y);
 	    if (h < height)
 		XFillRectangle(Xdisplay, TermWin.pixmap, gc, 0, h,
 			       width, height - h + 1);
@@ -350,24 +343,22 @@ resize_pixmap(void)
 		    p = 0;
 		if (y < 0)
 		    continue;
-	    /* copy one row from the tmp pixmap to the main pixmap */
+		/* copy one row from the tmp pixmap to the main pixmap */
 		XCopyArea(Xdisplay, tmp, TermWin.pixmap, gc,
 			  0, (int)p, width, 1, 0, y);
 	    }
 	    XFreePixmap(Xdisplay, tmp);
 	}
     }
-
 # ifdef XPM_BUFFERING
     if (TermWin.buf_pixmap)
 	XFreePixmap(Xdisplay, TermWin.buf_pixmap);
     TermWin.buf_pixmap = XCreatePixmap(Xdisplay, TermWin.vt,
 				       width, height, Xdepth);
-    if (!bgPixmap.pixmap) { 	/* we don't have a specified pixmap */
+    if (!bgPixmap.pixmap) {	/* we don't have a specified pixmap */
 	TermWin.pixmap = XCreatePixmap(Xdisplay, TermWin.vt,
 				       width, height, Xdepth);
-	XFillRectangle(Xdisplay, TermWin.pixmap, gc,
-		       0, 0, width, height);
+	XFillRectangle(Xdisplay, TermWin.pixmap, gc, 0, 0, width, height);
     }
     if (tiled == 0) {
 	XCopyArea(Xdisplay, TermWin.pixmap, TermWin.buf_pixmap, gc,
@@ -376,9 +367,9 @@ resize_pixmap(void)
 	int             i, j, w, h;
 
 	for (j = 0; j < height; j += xpmAttr.height) {
-	    h = (j + xpmAttr.height > height) ? (height - j): xpmAttr.height;
+	    h = (j + xpmAttr.height > height) ? (height - j) : xpmAttr.height;
 	    for (i = 0; i < width; i += xpmAttr.width) {
-		w = (i + xpmAttr.width > width) ? (width - i): xpmAttr.width;
+		w = (i + xpmAttr.width > width) ? (width - i) : xpmAttr.width;
 		XCopyArea(Xdisplay, TermWin.pixmap, TermWin.buf_pixmap, gc,
 			  0, 0, w, h, i, j);
 	    }
@@ -398,14 +389,12 @@ resize_pixmap(void)
     XClearWindow(Xdisplay, TermWin.vt);
 
     XSync(Xdisplay, False);
-#endif				/* XPM_BACKGROUND */
 }
 
 /* EXTPROTO */
 Pixmap
 set_bgPixmap(const char *file)
 {
-#ifdef XPM_BACKGROUND
     char           *f;
 
     assert(file != NULL);
@@ -419,9 +408,9 @@ set_bgPixmap(const char *file)
     if (*file != '\0') {
 /*      XWindowAttributes attr; */
 
-    /*
-     * we already have the required attributes
-     */
+	/*
+	 * we already have the required attributes
+	 */
 /*      XGetWindowAttributes(Xdisplay, TermWin.vt, &attr); */
 
 	xpmAttr.closeness = 30000;
@@ -431,16 +420,15 @@ set_bgPixmap(const char *file)
 	xpmAttr.valuemask = (XpmCloseness | XpmColormap | XpmVisual |
 			     XpmDepth | XpmSize | XpmReturnPixels);
 
-    /* search environment variables here too */
+	/* search environment variables here too */
 	if ((f = (char *)File_find(file, ".xpm")) == NULL
 	    || XpmReadFileToPixmap(Xdisplay, Xroot, f,
-				   &bgPixmap.pixmap,
-				   NULL, &xpmAttr)) {
+				   &bgPixmap.pixmap, NULL, &xpmAttr)) {
 	    char           *p;
 
-	/* semi-colon delimited */
-	    if ((p = strchr(file, ';')) == NULL)
-		p = strchr(file, '\0');
+	    /* semi-colon delimited */
+	    if ((p = STRCHR(file, ';')) == NULL)
+		p = STRCHR(file, '\0');
 
 	    print_error("couldn't load XPM file \"%.*s\"", (p - file), file);
 	}
@@ -448,5 +436,6 @@ set_bgPixmap(const char *file)
     }
     resize_pixmap();
     return bgPixmap.pixmap;
-#endif				/* XPM_BACKGROUND */
 }
+
+#endif				/* XPM_BACKGROUND */
